==> eiffelstudio-18.01.10.1424.tar: F_code/C8/gb395.c <==
/*
 * Code for class GB_EV_LIST_ITEM_LIST_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb395.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_LIST_ITEM_LIST_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F659_6513_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 658, Current, 0, 0, 6831);
	RTGC;
	RTOSP (6513);
#define Result RTOSR(6513)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("select_actions",14,182262387);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("deselect_actions",16,781601907);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	F431_5905(RTCW(Result));
	RTOSE (6513);
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F659_6513 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6513,F659_6513_body,(Current));
}

/* {GB_EV_LIST_ITEM_LIST_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F659_6514_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 658, Current, 0, 0, 6832);
	RTGC;
	RTOSP (6514);
#define Result RTOSR(6514)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6514);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F659_6514 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6514,F659_6514_body,(Current));
}

/* {GB_EV_LIST_ITEM_LIST_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F659_6515_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 658, Current, 0, 0, 6833);
	RTGC;
	RTOSP (6515);
#define Result RTOSR(6515)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when an item is selected.",52,2130465582);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("-- Actions to be performed when an item is deselected.",54,284349742);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6515);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F659_6515 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6515,F659_6515_body,(Current));
}

void EIF_Minit395 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C8/gb395.c <==
/*
 * Code for class GB_EV_WINDOW_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb395.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_WINDOW_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F659_6513_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 658, Current, 0, 0, 6831);
	RTGC;
	RTOSP (6513);
#define Result RTOSR(6513)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("move_actions",12,629373043);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("show_actions",12,1052154995);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("close_request_actions",21,1191586931);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(5);
	F431_5905(RTCW(Result));
	RTOSE (6513);
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F659_6513 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6513,F659_6513_body,(Current));
}

/* {GB_EV_WINDOW_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F659_6514_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 658, Current, 0, 0, 6832);
	RTGC;
	RTOSP (6514);
#define Result RTOSR(6514)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_GEOMETRY_ACTION_SEQUENCE",27,1784906821);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6514);
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F659_6514 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6514,F659_6514_body,(Current));
}

/* {GB_EV_WINDOW_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F659_6515_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 658, Current, 0, 0, 6833);
	RTGC;
	RTOSP (6515);
#define Result RTOSR(6515)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when window moves.",45,53229358);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("-- Actions to be performed when window is shown.",48,776309038);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("-- Actions to be performed when a request to close window has been received.",76,1211430702);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6515);
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F659_6515 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6515,F659_6515_body,(Current));
}

void EIF_Minit395 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
